@@ -17,6 +17,7 @@ import static org.eclipse.che.api.factory.shared.Constants.URL_PARAMETER_NAME;
 import static org.eclipse.che.api.workspace.server.devfile.Constants.CURRENT_API_VERSION;
 import static org.eclipse.che.dto.server.DtoFactory.newDto;
 import static org.mockito.ArgumentMatchers.any;
+import static org.mockito.ArgumentMatchers.anyBoolean;
 import static org.mockito.ArgumentMatchers.anyMap;
 import static org.mockito.ArgumentMatchers.eq;
 import static org.mockito.Mockito.mock;
@@ -58,7 +59,7 @@ public class BitbucketServerAuthorizingFactoryParametersResolverTest {
 
   @Mock private DevfileFilenamesProvider devfileFilenamesProvider;
 
-  BitbucketURLParser bitbucketURLParser;
+  BitbucketServerURLParser bitbucketURLParser;
 
   @Mock private GitCredentialManager gitCredentialManager;
   @Mock private PersonalAccessTokenManager personalAccessTokenManager;
@@ -69,7 +70,7 @@ public class BitbucketServerAuthorizingFactoryParametersResolverTest {
   @BeforeMethod
   protected void init() {
     bitbucketURLParser =
-        new BitbucketURLParser(
+        new BitbucketServerURLParser(
             "http://bitbucket.2mcl.com",
             devfileFilenamesProvider,
             mock(PersonalAccessTokenManager.class));
@@ -110,7 +111,8 @@ public class BitbucketServerAuthorizingFactoryParametersResolverTest {
 
     when(urlFactoryBuilder.buildDefaultDevfile(any())).thenReturn(computedFactory.getDevfile());
 
-    when(urlFactoryBuilder.createFactoryFromDevfile(any(RemoteFactoryUrl.class), any(), anyMap()))
+    when(urlFactoryBuilder.createFactoryFromDevfile(
+            any(RemoteFactoryUrl.class), any(), anyMap(), anyBoolean()))
         .thenReturn(Optional.empty());
     Map<String, String> params = ImmutableMap.of(URL_PARAMETER_NAME, bitbucketUrl);
     // when
@@ -127,11 +129,13 @@ public class BitbucketServerAuthorizingFactoryParametersResolverTest {
   @Test
   public void shouldSetDefaultProjectIntoDevfileIfNotSpecified() throws Exception {
 
-    String bitbucketUrl = "http://bitbucket.2mcl.com/scm/test/repo.git?at=foobar";
+    String bitbucketUrl =
+        "http://bitbucket.2mcl.com/users/test/repos/repo/browse?at=refs%2Fheads%2Ffoobar";
 
     FactoryDto computedFactory = generateDevfileFactory();
 
-    when(urlFactoryBuilder.createFactoryFromDevfile(any(RemoteFactoryUrl.class), any(), anyMap()))
+    when(urlFactoryBuilder.createFactoryFromDevfile(
+            any(RemoteFactoryUrl.class), any(), anyMap(), anyBoolean()))
         .thenReturn(Optional.of(computedFactory));
 
     Map<String, String> params = ImmutableMap.of(URL_PARAMETER_NAME, bitbucketUrl);
@@ -141,18 +145,20 @@ public class BitbucketServerAuthorizingFactoryParametersResolverTest {
     // then
     assertNotNull(factory.getDevfile());
     SourceDto source = factory.getDevfile().getProjects().get(0).getSource();
-    assertEquals(source.getLocation(), "http://bitbucket.2mcl.com/scm/test/repo.git");
-    assertEquals(source.getBranch(), "foobar");
+    assertEquals(source.getLocation(), "http://bitbucket.2mcl.com/scm/~test/repo.git");
+    assertEquals(source.getBranch(), "refs%2Fheads%2Ffoobar");
   }
 
   @Test
   public void shouldSetScmInfoIntoDevfileV2() throws Exception {
 
-    String bitbucketUrl = "http://bitbucket.2mcl.com/scm/test/repo.git?at=foobar";
+    String bitbucketUrl =
+        "http://bitbucket.2mcl.com/users/test/repos/repo/browse?at=refs%2Fheads%2Ffoobar";
 
     FactoryDevfileV2Dto computedFactory = generateDevfileV2Factory();
 
-    when(urlFactoryBuilder.createFactoryFromDevfile(any(RemoteFactoryUrl.class), any(), anyMap()))
+    when(urlFactoryBuilder.createFactoryFromDevfile(
+            any(RemoteFactoryUrl.class), any(), anyMap(), anyBoolean()))
         .thenReturn(Optional.of(computedFactory));
 
     Map<String, String> params = ImmutableMap.of(URL_PARAMETER_NAME, bitbucketUrl);
@@ -163,7 +169,7 @@ public class BitbucketServerAuthorizingFactoryParametersResolverTest {
     ScmInfo scmInfo = factory.getScmInfo();
     assertNotNull(scmInfo);
     assertEquals(scmInfo.getScmProviderName(), "bitbucket");
-    assertEquals(scmInfo.getRepositoryUrl(), "http://bitbucket.2mcl.com/scm/test/repo.git");
+    assertEquals(scmInfo.getRepositoryUrl(), "http://bitbucket.2mcl.com/scm/~test/repo.git");
     assertEquals(scmInfo.getBranch(), "foobar");
   }
 
